{{ form.non_field_errors }}

{% if form.fieldsets %}
    {% for fieldset in form.fieldsets %}
        <fieldset class="{{ fieldset.classes }}">
            {% if fieldset.legend %}
                <legend>{{ fieldset.legend }}</legend>
            {% endif %}
            {% if fieldset.description %}
                <p class="description">{{ fieldset.description }}</p>
            {% endif %}
            {% for field in fieldset %}
                {% include 'dartcms/forms/partial/horizontal_field.html' %}
            {% endfor %}
        </fieldset>
    {% endfor %}
{% else %}
    <fieldset>
        {% for field in form %}
            {% include 'dartcms/forms/partial/horizontal_field.html' %}
        {% endfor %}
    </fieldset>
{% endif %}

