body{background:#d9e0e7}.content{padding-left:260px}@media screen and (max-width:1024px){.content{padding-left:0}}.page-content{padding:0 20px}.form-window{width:350px;margin:100px auto}.input-group-addon i.fa{width:12px}.errorlist{margin:5px 0 15px 0;padding:8px;background-color:#f2dede;border-color:#eed3d7;color:#b94a48;list-style:none;border-radius:4px;-moz-border-radius:4px;-webkit-border-radius:4px}.errorlist li{margin-bottom:5px}.errorlist li:last-child{margin-bottom:0}.form-inline .form-group{margin-right:10px;position:relative;top:3px}.form-inline .form-group label{margin-right:10px}.form-inline .form-group .datetime{width:150px}.form-inline .form-group .date,.form-inline .form-group .time{width:100px}.form-inline .checkbox{position:relative;top:-4px}.empty-formset-form{display:none}.form-modal{left:260px;margin-left:-260px;overflow:visible}.form-modal a.close-modal{top:6px;right:6px}.multiselect-container li a label{padding:3px 20px !important}.multiselect-container li a label input{width:0 !important;height:0 !important}.search-form-wrapper form .form-control{max-width:200px;margin-bottom:5px}.mce-content-body{background:#fff !important}.grid-wrapper{height:600px;width:100%}.grid-loading-indicator span{margin-left:5px;font-size:11px;font-weight:normal}.navbar-toggle{float:left}@media (min-width:768px){.navbar-toggle{display:block}}@media (min-width:1024px){.navbar-toggle{display:none}}.navmenu-default,.navbar-default .navbar-offcanvas{background:#2d353c;border:0;width:260px}.navmenu-default .navmenu-brand,.navbar-default .navbar-offcanvas .navmenu-brand{padding:7px 15px 8px 15px;margin:0;background:#fff}.navmenu-default .navmenu-brand:hover,.navbar-default .navbar-offcanvas .navmenu-brand:hover{background:#f5f5f5}.navmenu-default .user-info,.navbar-default .navbar-offcanvas .user-info{background:#1a2229;padding:25px 15px}.navmenu-default .user-info .user-avatar,.navbar-default .navbar-offcanvas .user-info .user-avatar{float:left}.navmenu-default .user-info .user-meta,.navbar-default .navbar-offcanvas .user-info .user-meta{padding-left:60px}.navmenu-default .user-info .user-meta .user-name,.navbar-default .navbar-offcanvas .user-info .user-meta .user-name{color:#fff;padding-bottom:10px}.navmenu-default li a,.navbar-default .navbar-offcanvas li a{font-size:13px;color:#a8acb1 !important;padding:12px 15px}.navmenu-default li a i.fa,.navbar-default .navbar-offcanvas li a i.fa{margin-right:10px}.navmenu-default li a .caret,.navbar-default .navbar-offcanvas li a .caret{float:right;position:relative;top:8px;border-top-color:#a8acb1 !important;border-bottom-color:#a8acb1 !important}.navmenu-default li a:hover,.navbar-default .navbar-offcanvas li a:hover{color:#fff !important}.navmenu-default li.open a,.navbar-default .navbar-offcanvas li.open a{background-color:#232a2f !important;color:#fff !important}.navmenu-default li.open a .caret,.navbar-default .navbar-offcanvas li.open a .caret{border-top-color:#fff !important;border-bottom-color:#fff !important}.navmenu-default li .dropdown-menu,.navbar-default .navbar-offcanvas li .dropdown-menu{background-color:#1a2229 !important}.navmenu-default li .dropdown-menu li,.navbar-default .navbar-offcanvas li .dropdown-menu li{padding:0 20px}.navmenu-default li .dropdown-menu li a,.navbar-default .navbar-offcanvas li .dropdown-menu li a{background:#1a2229 !important;font-size:12px}.breadcrumb{position:relative;top:8px}#id-fm-layout .panel{border-radius:0}#id-fm-layout .panel.layout-panel-west{border-right:1px solid #eee}#id-fm-layout .panel .panel-header,#id-fm-layout .panel .panel-body{border-radius:0 !important}